import axios, { AxiosInstance, AxiosRequestConfig, AxiosResponse, AxiosError } from 'axios';
import { MessagePlugin } from 'tdesign-vue-next';

// 创建axios实例
const service: AxiosInstance = axios.create({
    baseURL: '/api',
    timeout: 50000, // 请求超时时间
});


// request拦截器
service.interceptors.request.use(
    (config: AxiosRequestConfig) => {

        // get参数编码
        if (config.method === 'get' && config.params) {
            let url = config.url as string;
            url += '?';
            const keys = Object.keys(config.params);
            for (const key of keys) {
                if (config.params[key] !== void 0 && config.params[key] !== null) {
                    url += `${key}=${encodeURIComponent(config.params[key])}&`;
                }
            }
            url = url.substring(0, url.length - 1);
            config.params = {};
            config.url = url;
        }


        return config;
    },
    (error: AxiosError) => {
        console.log(error);
        Promise.reject(error);
    },
);

// response 拦截器
service.interceptors.response.use(
    async (response: AxiosResponse<any>) => {

        if (response.config.responseType === 'blob') {
            // 如果是文件流，直接
            return response;
        }
        if (response.data.code === 200) {
            return response.data;
        }
        if (response.data.msg.includes('Token无效')) {
            localStorage.clear();
            window.location.href = '/'; // 去登录页
            return;
        }
        MessagePlugin.error(response.data.msg);
        return Promise.reject(response.data.msg);
    },
    (error: AxiosError) => {
        console.log(`err${error}`);
        return Promise.reject(error);
    },
);

export { service };
